@@ -54,6 +54,6 @@ def plot_progress(cache, experiment_id='', plot_keys=[], num_points=31, epoch=No
                 ax.set_xticklabels(xticks_range)
 
             _plt.xlabel('Epochs')
-            _plt.savefig(cache['log_dir'] + _os.sep + f"{experiment_id}_{k}_{plot_id}.png")
+            _plt.savefig(cache['log_dir'] + _os.sep + f"{experiment_id}_{k}_{plot_id}.png", bbox_inches='tight')
             _plt.close('all')
             i = j
